@@ -271,7 +271,7 @@ void bfield_fire_gun( int type /* ST_... */, Vector *dest, double alpha, double
 	Vector pos;
 
 	/* must not be too near to gun */
-	if ( dest->x < 70 && abs(dest->y-bfield.gun.y) < 50 )
+	if ( dest->x < STRIP_OFFSET )
 		return;
 	
 	pos = bfield.gun;
@@ -352,24 +352,6 @@ void bfield_reload_gun()
 	}
 }
 
-static void trees_check_impact( int x, int y, int radius )
-{
-	Tree *tree;
-	int i;
-	
-	for ( i = 0; i < bfield.tree_count; i++ ) {
-		tree = &bfield.trees[i];
-		if ( tree->dead ) continue;
-		if ( DIST( tree->x+tree->hx, tree->y+tree->hy, x, y ) < radius ) {
-			/* it burns! */
-			particles_add_emitter( PT_FIRE,
-					tree->x+tree->hx, tree->y+tree->hy,
-					5, 0.1, 10000 );
-			tree->burn_time = 10000;
-		}
-	}
-}
-
 void bfield_handle_impact( Shot *shot )
 {
 	SDL_Rect drect;
@@ -392,7 +374,6 @@ void bfield_handle_impact( Shot *shot )
 		SDL_PlaySound( wav_expl1 );
 		
 		units_check_impact( sx, sy, 20 );
-		trees_check_impact( sx, sy, 20 );
 		break;
 	    case ST_BOMB:
 		particles_explode_bomb( sx, sy );
@@ -404,7 +385,6 @@ void bfield_handle_impact( Shot *shot )
 		SDL_PlaySound( wav_expl2 );
 
 		units_check_impact( sx, sy, 40 );
-		trees_check_impact( sx, sy, 30 );
 		break;
 	    case ST_CLUSTER:
 		particles_explode_clusterbomb( sx, sy );
@@ -427,7 +407,6 @@ void bfield_handle_impact( Shot *shot )
 					RAND(20,60), 0.01 + (double)RAND(0, 20)/100 );
 			
 			units_check_impact( sx, sy, 40 );
-			trees_check_impact( sx, sy, 40 );
 		}
 		break;
 	    case ST_OIL:
@@ -454,4 +433,3 @@ void bfield_update_gun_dir( int mx, int my )
 	
 	bfield.img_gun_x_offset = gun_w * bfield.gun_dir;
 }
-
