@@ -1,6 +1,6 @@
 /***************************************************************************
     copyright            : (C) 2003 by Michael Speck
-    email                : kulkanie@gmx.net
+    email                : http://lgames.sf.net
  ***************************************************************************/
 
 /***************************************************************************
