@@ -170,7 +170,7 @@ static void set_video_mode()
 			video_sh = 480;
 		}
 		printf("Using scale factor %s\n",
-				(video_scale==2)?"2":((video_scale==1)?"1.5":0));
+				(video_scale==2)?"2":((video_scale==1)?"1.5":"0"));
 		video_xoff = (w - video_sw) / 2;
 		video_yoff = (h - video_sh) / 2;
 	}
@@ -487,7 +487,7 @@ static void take_screenshot()
 	static int i;
 	sprintf( buf, "screenshot%i.bmp", i++ );
 	SDL_SaveBMP( screen, buf );
-
+	printf("Taking screenshot ... saving it to %s\n",buf);
 }
 
 static void game_init()
@@ -739,8 +739,10 @@ static void main_loop()
 			input_delay = INPUT_DELAY;
 		}
 		/* take screenshots anywhere */
-		if ( keystate[SDLK_TAB] )
+		if ( keystate[SDLK_TAB] ) {
 			take_screenshot();
+			input_delay = INPUT_DELAY;
+		}
 	}
 
 	frame_time = SDL_GetTicks() - frame_time;
