@@ -15,7 +15,7 @@
 #include "units.h"
 
 extern SDL_Surface *img_units;
-extern SDL_Sound *wav_scream1, *wav_scream2, *wav_expl3;
+extern SDL_Sound *wav_expl3;
 extern int player_score;
 extern int audio_on;
 
@@ -164,7 +164,7 @@ void units_update( int ms )
 		/* move */
 		if ( unit->move_time > 0 ) {
 			/* animate */
-			if ( unit->type == UT_SOLDIER ) {
+			if ( unit->frame_count > 1 ) {
 				unit->frame += unit->frame_change * ms;
 				if ( unit->frame >= unit->frame_count ) {
 					unit->frame = 1; /* start at the beginning, frame 0
@@ -220,12 +220,14 @@ void unit_start_move( Unit *unit, Vector *dest )
 	len /= unit->speed;
 	unit->dir.x /= len; unit->dir.y /= len;
 
+	/* soldier has 8 looking directions in theory; practically it only
+	 * looks up or down; other units only move in one fixed direction */
 	if ( unit->type == UT_SOLDIER )
 		unit->frame_y_offset = 
 			unit->h * pos2dir( unit->pos.x, unit->pos.y, dest->x, dest->y );
 	
-	/* animation starts at frame 1 as frame 0 is the standing figure */
-	if ( unit->type == UT_SOLDIER )
+	/* animation starts at frame 1 as frame 0 is the standing unit */
+	if ( unit->frame_count > 1)
 		unit->frame = 1;
 }
 
@@ -243,7 +245,7 @@ void units_add_soldier( int strip_id, int x, int y, int move_up )
 	pos.x = STRIP_OFFSET + strip_id * STRIP_SIZE + x; pos.y = y; pos.z = 0;
 	unit = unit_create_basic( 
 			UT_SOLDIER, 
-			img_units, 0, 0, 12, 12, 5, 0.006, 0.012, &pos );
+			img_units, 0, 0, 12, 12, 1, 0.0, 0.012, &pos );
 	if ( !unit ) return;
 	unit->frame_y_offset = move_up?0:(unit->h*4);
 	unit->hx = 5; unit->hy = 9;
@@ -304,14 +306,6 @@ void units_check_impact( int x, int y, int radius )
 						unit->pos.x+unit->hx,
 						unit->pos.y+unit->hy, 
 						x,y );
-				if ( rand() % 2 ) {
-					if ( rand() % 2 ) {
-						SDL_PlaySound( wav_scream1 );
-					}
-					else {
-						SDL_PlaySound( wav_scream2 );
-					}
-				}
 				next = unit->next;
 				unit_delete( unit );
 				unit = next;
@@ -397,6 +391,3 @@ Unit *units_get_first_soldier()
 
 	return 0;
 }
-
-
-
